@@ -1,3 +1,8 @@
+# Copyright (C) 2020-2021, François-Guillaume Fernandez.
+
+# This program is licensed under the Apache License version 2.
+# See LICENSE or go to <https://www.apache.org/licenses/LICENSE-2.0.txt> for full license details.
+
 import numpy as np
 from matplotlib import cm
 from PIL import Image
@@ -6,6 +11,14 @@ from PIL import Image
 def overlay_mask(img: Image.Image, mask: Image.Image, colormap: str = 'jet', alpha: float = 0.7) -> Image.Image:
     """Overlay a colormapped mask on a background image
 
+    Example::
+        >>> from PIL import Image
+        >>> import matplotlib.pyplot as plt
+        >>> from torchcam.utils import overlay_mask
+        >>> img = ...
+        >>> cam = ...
+        >>> overlay = overlay_mask(img, cam)
+
     Args:
         img: background image
         mask: mask to be overlayed in grayscale
@@ -14,6 +27,10 @@ def overlay_mask(img: Image.Image, mask: Image.Image, colormap: str = 'jet', alp
 
     Returns:
         overlayed image
+
+    Raises:
+        TypeError: when the arguments have invalid types
+        ValueError: when the alpha argument has an incorrect value
     """
 
     if not isinstance(img, Image.Image) or not isinstance(mask, Image.Image):
